/**
 * @license
 * Copyright 2021 SimpleCore All Rights Reserved.
 *
 * Use of this source code is governed private licensing for
 * internal SimpleCore projects
 */
import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter } from '@angular/core';
import * as i0 from "@angular/core";
/** Change event object emitted by CoreCheckbox. */
export declare class CoreCheckboxChange {
    /** The source CoreCheckbox of the event. */
    source: CoreCheckbox;
    /** The new `checked` value of the checkbox. */
    checked: boolean;
}
/**
 * Provider Expression that allows core-checkbox to register as a ControlValueAccessor.
 * This allows it to support the FormsModule and [(ngModel)].
 */
export declare const CORE_CHECKBOX_CONTROL_VALUE_ACCESSOR: any;
export declare class CoreCheckbox implements AfterViewInit {
    private _changeDetectorRef;
    /**
     * Attached to the aria-label attribute of the host element. In most cases, aria-labelledby will
     * take precedence so this may be omitted.
     */
    ariaLabel: string;
    /**
     * Users can specify the `aria-labelledby` attribute which will be forwarded to the input element
     */
    ariaLabelledby: string | null;
    /** The 'aria-describedby' attribute is read after the element's label and field type. */
    ariaDescribedby: string;
    private _uniqueId;
    /** A unique id for the checkbox input. If none is supplied, it will be auto-generated. */
    id: string;
    /** Returns the unique id for the visual hidden input. */
    get inputId(): string;
    /** Whether the checkbox is required. */
    required: boolean;
    /** Whether the label should appear after or before the checkbox. Defaults to 'after' */
    labelPosition: 'before' | 'after';
    /** Name value will be applied to the input element if present */
    name: string | null;
    /** Event emitted when the checkbox's `checked` value changes. */
    readonly change: EventEmitter<CoreCheckboxChange>;
    /** Event emitted when the checkbox's `indeterminate` value changes. */
    readonly indeterminateChange: EventEmitter<boolean>;
    /** The value attribute of the native input element */
    value: string;
    /** Tab index */
    tabIndex: number;
    /**
     * Whether the checkbox is checked.
     */
    get checked(): boolean;
    set checked(value: boolean);
    private _checked;
    /**
     * Whether the checkbox is disabled. This fully overrides the implementation provided by
     * mixinDisabled, but the mixin is still required because mixinTabIndex requires it.
     */
    get disabled(): any;
    set disabled(value: any);
    private _disabled;
    checkboxSize: string;
    backgroundColor: string;
    labelElement: ElementRef;
    _inputElement: ElementRef;
    /**
     * Called when the checkbox is blurred. Needed to properly implement ControlValueAccessor.
     */
    _onTouched: () => any;
    private _controlValueAccessorChangeFn;
    constructor(_changeDetectorRef: ChangeDetectorRef);
    ngAfterViewInit(): void;
    getAriaChecked(): 'true' | 'false';
    onInputClick(event: Event): void;
    private _emitChangeEvent;
    /** Toggles the `checked` state of the checkbox. */
    toggle(): void;
    writeValue(value: any): void;
    registerOnChange(fn: (value: any) => void): void;
    registerOnTouched(fn: any): void;
    setDisabledState(isDisabled: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CoreCheckbox, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CoreCheckbox, "core-checkbox", ["coreCheckbox"], { "color": "color"; "tabIndex": "tabIndex"; "ariaLabel": "aria-label"; "ariaLabelledby": "aria-labelledby"; "ariaDescribedby": "aria-describedby"; "id": "id"; "required": "required"; "labelPosition": "labelPosition"; "name": "name"; "value": "value"; "checked": "checked"; "disabled": "disabled"; "checkboxSize": "checkboxSize"; "backgroundColor": "backgroundColor"; }, { "change": "change"; "indeterminateChange": "indeterminateChange"; }, never, ["*"], false, never>;
}
